@@ -2,15 +2,19 @@
 OS Level controlling class invokes startup, shutdown and handles signals.
 
 """
-import helper
 import logging
-from helper import parser
+import os
 import signal
 import sys
 
-from rejected import common
-from rejected import mcp
-from rejected import __version__
+import helper
+from helper import parser
+try:
+    import raven
+except ImportError:
+    raven = None
+
+from rejected import mcp, utils, __version__
 
 LOGGER = logging.getLogger(__name__)
 
@@ -20,6 +24,24 @@ class Controller(helper.Controller):
     of the OS level concerns.
 
     """
+    def __init__(self, *args, **kwargs):
+        super(Controller, self).__init__(*args, **kwargs)
+        self._mcp = None
+        self._sentry_client = None
+        if raven and self.config.application.get('sentry_dsn'):
+            kwargs = {
+                'exclude_paths': ['tornado'],
+                'include_paths': ['pika',
+                                  'helper',
+                                  'rejected'],
+                'processors': ['raven.processors.SanitizePasswordsProcessor']
+            }
+            if os.environ.get('ENVIRONMENT'):
+                kwargs['environment'] = os.environ['ENVIRONMENT']
+            kwargs['version'] = __version__
+            self._sentry_client = raven.Client(
+                self.config.application['sentry_dsn'], **kwargs)
+
     def _master_control_program(self):
         """Return an instance of the MasterControlProgram.
 
@@ -31,7 +53,8 @@ class Controller(helper.Controller):
                                         profile=self.args.profile,
                                         quantity=self.args.quantity)
 
-    def _prepend_python_path(self, path):  #pragma: no cover
+    @staticmethod
+    def _prepend_python_path(path):  # pragma: no cover
         """Add the specified value to the python path.
 
         :param str path: The path to append
@@ -43,7 +66,6 @@ class Controller(helper.Controller):
     def setup(self):
         """Continue the run process blocking on MasterControlProgram.run"""
         # If the app was invoked to specified to prepend the path, do so now
-        common.add_null_handler()
         if self.args.prepend_path:
             self._prepend_python_path(self.args.prepend_path)
 
@@ -83,6 +105,14 @@ class Controller(helper.Controller):
             self._mcp.run()
         except KeyboardInterrupt:
             LOGGER.info('Caught CTRL-C, shutting down')
+        except Exception:
+            exc_info = sys.exc_info()
+            kwargs = {'logger': 'rejected.controller',
+                      'modules': utils.get_module_data()}
+            LOGGER.debug('Sending exception to sentry: %r', kwargs)
+            if self._sentry_client:
+                self._sentry_client.captureException(exc_info, **kwargs)
+            raise
         if self.is_running:
             self.stop()
 
@@ -95,7 +125,7 @@ def add_parser_arguments():
                            default=None,
                            dest='profile',
                            help='Profile the consumer modules, specifying '
-                                'the output directory.')
+                           'the output directory.')
     argparser.add_argument('-o', '--only',
                            action='store',
                            default=None,
@@ -108,10 +138,11 @@ def add_parser_arguments():
                            help='Prepend the python path with the value.')
     argparser.add_argument('-q', '--qty',
                            action='store',
-                           default=1,
+                           type=int,
+                           default=None,
                            dest='quantity',
-                           help='Run the specified quanty of consumer processes'
-                                ' when used in conjunction with -o')
+                           help='Run the specified quantity of consumer '
+                           'processes when used in conjunction with -o')
 
 
 def main():
